/*
 *  /MathJax/localization/scn/HelpDialog.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("scn","HelpDialog",{version:"2.7.4",isLoaded:true,strings:{Help:"Guida di MathJax",MathJax:"*MathJax* \u00E8 na libbrar\u00ECa JavaScript ca pirmetti a l'autura di m\u00E8ttiri f\u00F2rmuli matim\u00E0tichi nt\u00EA p\u00E0ggini web. Comu litturi, unu nun havi a fari nenti pi f\u00E0rilu funziunari.",Browsers:"*Browser*: MathJax funziona cu tutti li browser muderni cumprisi IE6+, Firefox 3+, Chrome 0.2+, Safari 2+, Opera 9.6+ e lu cchi\u00F9 d\u00EE browser purt\u00E0tili.",Menu:"*Men\u00F9 d\u00EE f\u00F2rmuli*: MathJax agghiunci nu men\u00F9 cuntistuali nta tutti li f\u00F2rmuli matim\u00E0tichi. Si grapi cliccannu supra d\u00EE f\u00F2rmuli c\u00FB buttuni drittu o tinennu carcatu ctrl.",ShowMath:"*Ammustra la f\u00F2rmula comu* pirmetti di taliari lu c\u00F2dici surgenti d\u00E2 f\u00F2rmula p\u00FB cupiari e ncuddari (sutta forma di MathML o nt\u00F4 s\u00F2 furmatu origginali).",Settings:"*Mpustazzioni* duna cuntrollu supra d\u00EE carattir\u00ECstichi di MathJax, comu p'esempiu la grannizza d\u00EE f\u00F2rmuli e lu miccanismu adupiratu pi visualizz\u00E0rili.",Language:"*Lingua* pirmetti di sc\u00E8gghiri la lingua adupirata di MathJax p\u00EE s\u00F2 men\u00F9 e p\u00EE s\u00F2 missagg\u00EE d'avvisu.",Zoom:"*Zoom d\u00EE f\u00F2rmuli*: si veni diff\u00ECcili a l\u00E8ggiri na f\u00F2rmula, MathJax la p\u00F2 fari cchi\u00F9 granni pi f\u00E0rila v\u00ECdiri megghiu.",Accessibilty:"*Accissibbilit\u00E0*: MathJax funziona autumaticamenti ch\u00EE littura di schermu pi r\u00E8nniri li f\u00F2rmuli matim\u00E0tichi acciss\u00ECbbili a cu havi prubblemi di vista.",Fonts:"*Tipi di car\u00E0ttiri*: MathJax ad\u00F2pira certi tipi di car\u00E0ttiri matim\u00E0tici quannu l'attrova istallati nt\u00F4 computer; sinn\u00F2, ad\u00F2pira tipi di car\u00E0ttiri scarricati di Internet. Nun servi pi forza aviri li tipi di car\u00E0ttiri istallati lucalmenti, per\u00F2 renni la mpagginazzioni cchi\u00F9 viloci. Nui cunzigghiamu di istallari li [tipi di car\u00E0ttiri STIX](%1)."}});MathJax.Ajax.loadComplete("[MathJax]/localization/scn/HelpDialog.js");
