/*
 *  /MathJax/localization/scn/MathML.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("scn","MathML",{version:"2.7.4",isLoaded:true,strings:{BadMglyph:"mglyph sbagghiatu: %1",BadMglyphFont:"Tipu di car\u00E0ttiri sbagghiatu: %1",MathPlayer:"MathJax nun arrinisc\u00ECu a armari lu MathPlayer.\n\nSi lu MathPlayer nun \u00E8 istallatu, pi prima cosa s'havi a istallari.\nSinn\u00F2, li t\u00F2 mpustazzioni d\u00E2 sicurizza purr\u00ECanu nun pirm\u00E8ttiri lu funziunamentu\nd\u00EE cuntrolli ActiveX. Grapi la vuci \u00ABOpzioni Internet\u00BB nt\u00F4 men\u00F9 \u00ABStrummenti\u00BB e pigghia la linguetta \u00ABSicurizza\u00BB, e dd\u00E0 carca lu buttuni \u00ABLiveddu pirsunalizzatu...\u00BB. Cuntrolla ch\u00EE mpustazzioni \u00ABEsegui cuntrolli ActiveX e plug-in\u00BB e \u00ABCumpurtamentu file binari e script\u00BB sunnu attivati.\n\nComu a ora vidi missagg\u00EE d'erruri mmeci chi f\u00F2rmuli matim\u00E0tichi mpagginati",CantCreateXMLParser:"MathJax nun p\u00F2 criari n'analizzaturi sint\u00E0tticu XML p\u00FB MathML. Cuntrolla chi \u00E8 attivata la mpustazzioni di sicurizza \u00ABEsegui script cuntrolli ActiveX contrassignati comu sicuri\u00BB (grapi la vuci \u00ABOpzioni Internet\u00BB nt\u00F4 men\u00F9 \u00ABStrummenti\u00BB, scegghi la linguetta \u00ABSicurizza\u00BB, e carca lu buttuni \u00ABLiveddu pirsunalizzatu...\u00BB p'attruvari sta mpustazzioni).\n\nL'equazzioni MathML nun ponnu \u00E8ssiri labburati di MathJax",UnknownNodeType:"Tipu di gruppu scanusciutu: %1",UnexpectedTextNode:"Gruppu di testu nun aspittatu: %1",ErrorParsingMathML:"Erruri nta l'an\u00E0lisi d\u00FB MathML",ParsingError:"Erruri nta l'an\u00E0lisi d\u00FB MathML: %1",MathMLSingleElement:"Lu MathML havi a \u00E8ssiri furmatu di n'elimentu s\u00ECngulu",MathMLRootElement:"Lu MathML havi a \u00E8ssiri furmatu di n'elimentu \u003Cmath\u003E, no %1"}});MathJax.Ajax.loadComplete("[MathJax]/localization/scn/MathML.js");
