/*
 *  /MathJax/localization/sl/FontWarnings.js
 *
 *  Copyright (c) 2009-2018 The MathJax Consortium
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

MathJax.Localization.addTranslation("sl","FontWarnings",{version:"2.7.4",isLoaded:true,strings:{webFont:"MathJax za prikaza matematike na tej strani uporablja spletne pisave. Da se te nalo\u017Eijo, vzame nekaj \u010Dasa. Stran bi se hitreje izrisovala, \u010De bi bile matemati\u010Dne pisave name\u0161\u010Dene neposredno v mapi s pisavami va\u0161ega sistema.",imageFonts:"MathJax ne uporablja lokalnih ali spletnih pisav, temve\u010D svoje slikovne pisave. Izrisovanje bo zato po\u010Dasnej\u0161e, matematika pa se morda ne bo natisnila v popolni lo\u010Dljivosti va\u0161ega tiskalnika.",noFonts:"MathJax ne more najti pisave za prikaz matematike, slikovne pisave pa niso na razpolago, zato v upanju, da jih bo va\u0161 brskalnik lahko prikazal, uporablja generi\u010Dne unikodne znake. Nekateri znaki morda ne bodo prikazani pravilno ali pa sploh ne bodo prikazani.",webFonts:"Ve\u010Dina sodobnih brskalnikov omogo\u010Da prenos pisav prek spleta. S posodobitvijo (ali zamenjavo) svojega brskalnika boste morda lahko izbolj\u0161ali kakovost matematike na tej strani.",fonts:"MathJax lahko uporablja [fonte STIX](%1) ali [fonte MathJax TeX](%2). Za izbolj\u0161anje svoje uporabni\u0161ke izku\u0161nje prenesite in namestite te fonte.",STIXPage:"Stran je oblikovana za uporabo [pisav STIX](%1). Za izbolj\u0161anje svoje uporabni\u0161ke izku\u0161nje prenesite in namestite te pisave.",TeXPage:"Stran je oblikovana za uporabo [pisav MathJax Tex](%1). Za izbolj\u0161anje svoje izku\u0161nje z MathJax prenesite in namestite te pisave."}});MathJax.Ajax.loadComplete("[MathJax]/localization/sl/FontWarnings.js");
